diff --git a/applications/solvers/compressible/rhoPimpleFoam/pEqn.H b/applications/solvers/compressible/rhoPimpleFoam/pEqn.H
index 9c4e9658cc703bb0234c79a797fdfee4d2c8b22d..0f3dfe450bccd217fa4e12925d8a5f082ce31b02 100644
--- a/applications/solvers/compressible/rhoPimpleFoam/pEqn.H
+++ b/applications/solvers/compressible/rhoPimpleFoam/pEqn.H
@@ -58,8 +58,6 @@ else
         //+ fvc::ddtPhiCorr(rUA, rho, U, phi)
         );
 
-    //bool closedVolume = adjustPhi(phi, U, p);
-
     for (int nonOrth=0; nonOrth<=nNonOrthCorr; nonOrth++)
     {
         // Pressure corrector
diff --git a/applications/solvers/heatTransfer/buoyantBoussinesqSimpleFoam/pEqn.H b/applications/solvers/heatTransfer/buoyantBoussinesqSimpleFoam/pEqn.H
index e1d42d738e8deff2eda578436baca131809f352f..6408c7ccc80754426579d2feab91af7e744a7bb8 100644
--- a/applications/solvers/heatTransfer/buoyantBoussinesqSimpleFoam/pEqn.H
+++ b/applications/solvers/heatTransfer/buoyantBoussinesqSimpleFoam/pEqn.H
@@ -7,6 +7,7 @@
 
     phi = fvc::interpolate(U) & mesh.Sf();
     adjustPhi(phi, U, p);
+
     surfaceScalarField buoyancyPhi =
         rUAf*fvc::interpolate(rhok)*(g & mesh.Sf());
     phi += buoyancyPhi;
diff --git a/applications/solvers/heatTransfer/buoyantSimpleFoam/pEqn.H b/applications/solvers/heatTransfer/buoyantSimpleFoam/pEqn.H
index e680e9421aee62a3dac1d09b8174005925399050..4bbb449df7250b144f84ac84ecaed6682c84be12 100644
--- a/applications/solvers/heatTransfer/buoyantSimpleFoam/pEqn.H
+++ b/applications/solvers/heatTransfer/buoyantSimpleFoam/pEqn.H
@@ -9,6 +9,7 @@
 
     phi = fvc::interpolate(rho)*(fvc::interpolate(U) & mesh.Sf());
     bool closedVolume = adjustPhi(phi, U, p);
+
     surfaceScalarField buoyancyPhi =
         rhorUAf*fvc::interpolate(rho)*(g & mesh.Sf());
     phi += buoyancyPhi;
diff --git a/applications/solvers/incompressible/pimpleDyMFoam/correctPhi.H b/applications/solvers/incompressible/pimpleDyMFoam/correctPhi.H
index 493c4e09297dda164af75b9c29b846be3ccf68e8..023ecc6d5a7e8afa95465df9db34b9a816d860e8 100644
--- a/applications/solvers/incompressible/pimpleDyMFoam/correctPhi.H
+++ b/applications/solvers/incompressible/pimpleDyMFoam/correctPhi.H
@@ -1,5 +1,9 @@
 {
-    wordList pcorrTypes(p.boundaryField().types());
+    wordList pcorrTypes
+    (
+        p.boundaryField().size(),
+        zeroGradientFvPatchScalarField::typeName
+    );
 
     for (label i=0; i<p.boundaryField().size(); i++)
     {
diff --git a/applications/solvers/multiphase/compressibleInterDyMFoam/compressibleInterDyMFoam.C b/applications/solvers/multiphase/compressibleInterDyMFoam/compressibleInterDyMFoam.C
index 65afde39c2dedd071b59d6dd39880e18880e486d..176900f0c63aaa65a7b8db19d0a2da8e1330614b 100644
--- a/applications/solvers/multiphase/compressibleInterDyMFoam/compressibleInterDyMFoam.C
+++ b/applications/solvers/multiphase/compressibleInterDyMFoam/compressibleInterDyMFoam.C
@@ -104,12 +104,6 @@ int main(int argc, char *argv[])
             #include "meshCourantNo.H"
         }
 
-        if (mesh.changing())
-        {
-            gh = g & mesh.C();
-            ghf = g & mesh.Cf();
-        }
-
         turbulence->correct();
 
         // --- Outer-corrector loop
diff --git a/applications/solvers/multiphase/compressibleInterDyMFoam/createFields.H b/applications/solvers/multiphase/compressibleInterDyMFoam/createFields.H
index 6b8e67cc4920d3da95a06c22b81db6dee407bc84..3da1b5e9c19d85ba9dede2bcdb85f346a5610c9e 100644
--- a/applications/solvers/multiphase/compressibleInterDyMFoam/createFields.H
+++ b/applications/solvers/multiphase/compressibleInterDyMFoam/createFields.H
@@ -46,11 +46,6 @@
     #include "createPhi.H"
 
 
-    Info<< "Calculating field g.h\n" << endl;
-    volScalarField gh("gh", g & mesh.C());
-    surfaceScalarField ghf("ghf", g & mesh.Cf());
-
-
     Info<< "Reading transportProperties\n" << endl;
     twoPhaseMixture twoPhaseProperties(U, phi);
 
@@ -134,7 +129,11 @@
     );
 
 
-    wordList pcorrTypes(p.boundaryField().types());
+    wordList pcorrTypes
+    (
+        p.boundaryField().size(),
+        zeroGradientFvPatchScalarField::typeName
+    );
 
     for (label i=0; i<p.boundaryField().size(); i++)
     {
diff --git a/applications/solvers/multiphase/interDyMFoam/correctPhi.H b/applications/solvers/multiphase/interDyMFoam/correctPhi.H
index 1f7845f347d25a2e9e45cdbd6539e1998022f5e4..0854a68b8e3ae1b941dbdad26c244017efc04d8e 100644
--- a/applications/solvers/multiphase/interDyMFoam/correctPhi.H
+++ b/applications/solvers/multiphase/interDyMFoam/correctPhi.H
@@ -1,5 +1,5 @@
 {
-#   include "continuityErrs.H"
+    #include "continuityErrs.H"
 
     volScalarField pcorr
     (
@@ -36,5 +36,5 @@
         }
     }
 
-#   include "continuityErrs.H"
+    #include "continuityErrs.H"
 }
diff --git a/applications/solvers/multiphase/interDyMFoam/createFields.H b/applications/solvers/multiphase/interDyMFoam/createFields.H
index 26644e17f472fe4dd8605280c0ed8e5a1ee0a5dd..905ba0d64656e7be4b5fa0acdcefd6710d31999f 100644
--- a/applications/solvers/multiphase/interDyMFoam/createFields.H
+++ b/applications/solvers/multiphase/interDyMFoam/createFields.H
@@ -92,7 +92,11 @@
         incompressible::turbulenceModel::New(U, phi, twoPhaseProperties)
     );
 
-    wordList pcorrTypes(p.boundaryField().types());
+    wordList pcorrTypes
+    (
+        p.boundaryField().size(),
+        zeroGradientFvPatchScalarField::typeName
+    );
 
     for (label i=0; i<p.boundaryField().size(); i++)
     {
diff --git a/applications/solvers/multiphase/interDyMFoam/interDyMFoam.C b/applications/solvers/multiphase/interDyMFoam/interDyMFoam.C
index cf8ec8eb323bdc42352669aae04249baa07426f1..466333ff3014a6fa3942a556846e6edd7ae49316 100644
--- a/applications/solvers/multiphase/interDyMFoam/interDyMFoam.C
+++ b/applications/solvers/multiphase/interDyMFoam/interDyMFoam.C
@@ -86,9 +86,6 @@ int main(int argc, char *argv[])
                 << " s" << endl;
         }
 
-        volScalarField gh("gh", g & mesh.C());
-        surfaceScalarField ghf("ghf", g & mesh.Cf());
-
         if (mesh.changing() && correctPhi)
         {
             #include "correctPhi.H"
diff --git a/applications/solvers/multiphase/interDyMFoam/pEqn.H b/applications/solvers/multiphase/interDyMFoam/pEqn.H
index 8825661c8307d70f2c8cb8bf6f18675579aaf6cb..2af289a76f31beb1654acfde23592bb299346f1c 100644
--- a/applications/solvers/multiphase/interDyMFoam/pEqn.H
+++ b/applications/solvers/multiphase/interDyMFoam/pEqn.H
@@ -5,19 +5,19 @@
     U = rAU*UEqn.H();
     surfaceScalarField phiU("phiU", (fvc::interpolate(U) & mesh.Sf()));
 
+    if (p.needReference())
+    {
+        fvc::makeRelative(phiU, U);
+        adjustPhi(phiU, U, p);
+        fvc::makeAbsolute(phiU, U);
+    }
+
     phi = phiU +
     (
         fvc::interpolate(interface.sigmaK())*fvc::snGrad(alpha1)*mesh.magSf()
       + fvc::interpolate(rho)*(g & mesh.Sf())
     )*rAUf;
 
-    if (p.needReference())
-    {
-        fvc::makeRelative(phi, U);
-        adjustPhi(phi, U, p);
-        fvc::makeAbsolute(phi, U);
-    }
-
     for(int nonOrth=0; nonOrth<=nNonOrthCorr; nonOrth++)
     {
         fvScalarMatrix pEqn
diff --git a/applications/solvers/multiphase/interFoam/correctPhi.H b/applications/solvers/multiphase/interFoam/correctPhi.H
index 642aa1c5d2a88c157d1d704f555c9b87ddefcc48..0274b7e9ed8dc75b372db31efa743722a7dafc56 100644
--- a/applications/solvers/multiphase/interFoam/correctPhi.H
+++ b/applications/solvers/multiphase/interFoam/correctPhi.H
@@ -1,7 +1,11 @@
 {
-#   include "continuityErrs.H"
+    #include "continuityErrs.H"
 
-    wordList pcorrTypes(p.boundaryField().types());
+    wordList pcorrTypes
+    (
+        p.boundaryField().size(),
+        zeroGradientFvPatchScalarField::typeName
+    );
 
     for (label i=0; i<p.boundaryField().size(); i++)
     {
@@ -46,5 +50,5 @@
         }
     }
 
-#   include "continuityErrs.H"
+    #include "continuityErrs.H"
 }
diff --git a/applications/solvers/multiphase/interFoam/pEqn.H b/applications/solvers/multiphase/interFoam/pEqn.H
index 25482fa9944a76a7de7ec2e94ced844068f420fa..7aa172b858473b0f5e5c0934e5690233ef60755a 100644
--- a/applications/solvers/multiphase/interFoam/pEqn.H
+++ b/applications/solvers/multiphase/interFoam/pEqn.H
@@ -7,17 +7,18 @@
     surfaceScalarField phiU
     (
         "phiU",
-        (fvc::interpolate(U) & mesh.Sf()) + fvc::ddtPhiCorr(rUA, rho, U, phi)
+        (fvc::interpolate(U) & mesh.Sf())
+      + fvc::ddtPhiCorr(rUA, rho, U, phi)
     );
 
+    adjustPhi(phiU, U, p);
+
     phi = phiU +
         (
             fvc::interpolate(interface.sigmaK())*fvc::snGrad(alpha1)*mesh.magSf()
           + fvc::interpolate(rho)*(g & mesh.Sf())
         )*rUAf;
 
-    adjustPhi(phi, U, p);
-
     for(int nonOrth=0; nonOrth<=nNonOrthCorr; nonOrth++)
     {
         fvScalarMatrix pEqn
diff --git a/applications/solvers/multiphase/interPhaseChangeFoam/correctPhi.H b/applications/solvers/multiphase/interPhaseChangeFoam/correctPhi.H
index 642aa1c5d2a88c157d1d704f555c9b87ddefcc48..17377302f0ecd97c2ee04e98cea8bcfc88ab4921 100644
--- a/applications/solvers/multiphase/interPhaseChangeFoam/correctPhi.H
+++ b/applications/solvers/multiphase/interPhaseChangeFoam/correctPhi.H
@@ -1,7 +1,11 @@
 {
-#   include "continuityErrs.H"
+    #include "continuityErrs.H"
 
-    wordList pcorrTypes(p.boundaryField().types());
+    wordList pcorrTypes
+    (
+        p.boundaryField().size(),
+        zeroGradientFvPatchScalarField::typeName
+    );
 
     for (label i=0; i<p.boundaryField().size(); i++)
     {
diff --git a/applications/solvers/multiphase/interPhaseChangeFoam/pEqn.H b/applications/solvers/multiphase/interPhaseChangeFoam/pEqn.H
index 4f290157f64bbf3de676acc26c9f5e708af91ba6..3c164cc574311612e838abda97310fd3959e9e72 100644
--- a/applications/solvers/multiphase/interPhaseChangeFoam/pEqn.H
+++ b/applications/solvers/multiphase/interPhaseChangeFoam/pEqn.H
@@ -11,14 +11,14 @@
       + fvc::ddtPhiCorr(rUA, rho, U, phi)
     );
 
+    adjustPhi(phiU, U, p);
+
     phi = phiU +
         (
             fvc::interpolate(interface.sigmaK())*fvc::snGrad(alpha1)*mesh.magSf()
           + fvc::interpolate(rho)*(g & mesh.Sf())
         )*rUAf;
 
-    adjustPhi(phi, U, p);
-
     Pair<tmp<volScalarField> > vDotP = twoPhaseProperties->vDotP();
     const volScalarField& vDotcP = vDotP[0]();
     const volScalarField& vDotvP = vDotP[1]();
diff --git a/applications/solvers/multiphase/multiphaseInterFoam/pEqn.H b/applications/solvers/multiphase/multiphaseInterFoam/pEqn.H
index 9d7e36dc95a0e695946f20a2e0fb4d9f80512b56..4bec77f950d54fadbefe8507abe3ed8699476c54 100644
--- a/applications/solvers/multiphase/multiphaseInterFoam/pEqn.H
+++ b/applications/solvers/multiphase/multiphaseInterFoam/pEqn.H
@@ -10,14 +10,14 @@
         (fvc::interpolate(U) & mesh.Sf()) + fvc::ddtPhiCorr(rUA, rho, U, phi)
     );
 
+    adjustPhi(phiU, U, p);
+
     phi = phiU +
         (
             mixture.surfaceTensionForce()*mesh.magSf()
           + fvc::interpolate(rho)*(g & mesh.Sf())
         )*rUAf;
 
-    adjustPhi(phi, U, p);
-
     for(int nonOrth=0; nonOrth<=nNonOrthCorr; nonOrth++)
     {
         fvScalarMatrix pEqn
diff --git a/bin/foamTemplates/sourceTemplate/newSourceTemplate b/bin/foamTemplates/sourceTemplate/newSourceTemplate
old mode 100644
new mode 100755
diff --git a/etc/bashrc b/etc/bashrc
index aae664f98a2986dd3fe6dbc2ec5de65470c9ea14..f906c99080ba679d8ea58dcb7d3f29b713b665e7 100644
--- a/etc/bashrc
+++ b/etc/bashrc
@@ -74,7 +74,7 @@ export WM_PROJECT_USER_DIR=$HOME/$WM_PROJECT/$USER-$WM_PROJECT_VERSION
 
 # Location of third-party software
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-export WM_THIRD_PARTY_DIR=$WM_PROJECT_INST_DIR/ThirdParty
+export WM_THIRD_PARTY_DIR=$WM_PROJECT_INST_DIR/ThirdParty-$WM_PROJECT_VERSION
 
 
 # Operating System/Platform
diff --git a/etc/controlDict b/etc/controlDict
index d7824f102ed9972cfb96cad9569659231d200daf..f06bbbd96123726a277fbb8a18a29ea084bb8d10 100644
--- a/etc/controlDict
+++ b/etc/controlDict
@@ -424,7 +424,7 @@ DebugSwitches
     filteredLinear3     0;
     filteredLinear3V    0;
     fixedEnthalpy       0;
-    fixedFluxBuoyantPressure 0;
+    buoyantPressure 0;
     fixedFluxBoussinesqBuoyantPressure 0;
     fixedFluxPressure   0;
     fixedGradient       0;
diff --git a/etc/cshrc b/etc/cshrc
index 3e6af0cd44890b8a4202babc1485ceaa981c274f..e1960e39dc71b9b2f29b1e9bd61826a9ef65b1e4 100644
--- a/etc/cshrc
+++ b/etc/cshrc
@@ -68,7 +68,7 @@ setenv WM_PROJECT_USER_DIR $HOME/$WM_PROJECT/$LOGNAME-$WM_PROJECT_VERSION
 
 # Location of third-party software
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-setenv WM_THIRD_PARTY_DIR $WM_PROJECT_INST_DIR/ThirdParty
+setenv WM_THIRD_PARTY_DIR $WM_PROJECT_INST_DIR/ThirdParty-$WM_PROJECT_VERSION
 
 
 # Operating System/Platform
diff --git a/src/OpenFOAM/fields/DimensionedFields/DimensionedField/DimensionedField.H b/src/OpenFOAM/fields/DimensionedFields/DimensionedField/DimensionedField.H
index f9744fc4fd954de3eb38b35073b74bfd1f7d1c64..1d26e508a53093541135f65409ddd7a80a72b5be 100644
--- a/src/OpenFOAM/fields/DimensionedFields/DimensionedField/DimensionedField.H
+++ b/src/OpenFOAM/fields/DimensionedFields/DimensionedField/DimensionedField.H
@@ -217,9 +217,8 @@ public:
         tmp<DimensionedField<Type, GeoMesh> > clone() const;
 
 
-    // Destructor
-
-        ~DimensionedField();
+    //- Destructor
+    virtual ~DimensionedField();
 
 
     // Member Functions
diff --git a/src/finiteVolume/Make/files b/src/finiteVolume/Make/files
index 37b59c523a3e541665964c469a5fbe75bee38012..54bfbc7cf6e4a46600704deee7add747fd581d92 100644
--- a/src/finiteVolume/Make/files
+++ b/src/finiteVolume/Make/files
@@ -108,7 +108,7 @@ $(derivedFvPatchFields)/advective/advectiveFvPatchFields.C
 $(derivedFvPatchFields)/directMappedFixedValue/directMappedFixedValueFvPatchFields.C
 $(derivedFvPatchFields)/directMappedVelocityFluxFixedValue/directMappedVelocityFluxFixedValueFvPatchField.C
 $(derivedFvPatchFields)/fan/fanFvPatchFields.C
-$(derivedFvPatchFields)/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.C
+$(derivedFvPatchFields)/buoyantPressure/buoyantPressureFvPatchScalarField.C
 $(derivedFvPatchFields)/fixedFluxPressure/fixedFluxPressureFvPatchScalarField.C
 $(derivedFvPatchFields)/fixedInternalValueFvPatchField/fixedInternalValueFvPatchFields.C
 $(derivedFvPatchFields)/fixedNormalSlip/fixedNormalSlipFvPatchFields.C
diff --git a/src/finiteVolume/cfdTools/general/include/readPISOControls.H b/src/finiteVolume/cfdTools/general/include/readPISOControls.H
index 5f14c2bcae2f56ecdfa998ba1224e6b3ad438d0a..de763e00b0c4b92769dcdbcdacbeec2049ec9a44 100644
--- a/src/finiteVolume/cfdTools/general/include/readPISOControls.H
+++ b/src/finiteVolume/cfdTools/general/include/readPISOControls.H
@@ -13,7 +13,3 @@
 
     int nOuterCorr =
         piso.lookupOrDefault<int>("nOuterCorrectors", 1);
-
-    bool ddtPhiCorr =
-        piso.lookupOrDefault<Switch>("ddtPhiCorr", false);
-
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.C b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
similarity index 81%
rename from src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.C
rename to src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
index 279918b47af95cdb9d91b7344ff5844af91888bd..cafc55aa3a534df59152b79f321556edef625290 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.C
+++ b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
@@ -24,7 +24,7 @@ License
 
 \*---------------------------------------------------------------------------*/
 
-#include "fixedFluxBuoyantPressureFvPatchScalarField.H"
+#include "buoyantPressureFvPatchScalarField.H"
 #include "addToRunTimeSelectionTable.H"
 #include "fvPatchFieldMapper.H"
 #include "volFields.H"
@@ -36,8 +36,8 @@ namespace Foam
 
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
-fixedFluxBuoyantPressureFvPatchScalarField::
-fixedFluxBuoyantPressureFvPatchScalarField
+buoyantPressureFvPatchScalarField::
+buoyantPressureFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF
@@ -48,8 +48,8 @@ fixedFluxBuoyantPressureFvPatchScalarField
 {}
 
 
-fixedFluxBuoyantPressureFvPatchScalarField::
-fixedFluxBuoyantPressureFvPatchScalarField
+buoyantPressureFvPatchScalarField::
+buoyantPressureFvPatchScalarField
 (
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
@@ -64,10 +64,10 @@ fixedFluxBuoyantPressureFvPatchScalarField
 }
 
 
-fixedFluxBuoyantPressureFvPatchScalarField::
-fixedFluxBuoyantPressureFvPatchScalarField
+buoyantPressureFvPatchScalarField::
+buoyantPressureFvPatchScalarField
 (
-    const fixedFluxBuoyantPressureFvPatchScalarField& ptf,
+    const buoyantPressureFvPatchScalarField& ptf,
     const fvPatch& p,
     const DimensionedField<scalar, volMesh>& iF,
     const fvPatchFieldMapper& mapper
@@ -78,10 +78,10 @@ fixedFluxBuoyantPressureFvPatchScalarField
 {}
 
 
-fixedFluxBuoyantPressureFvPatchScalarField::
-fixedFluxBuoyantPressureFvPatchScalarField
+buoyantPressureFvPatchScalarField::
+buoyantPressureFvPatchScalarField
 (
-    const fixedFluxBuoyantPressureFvPatchScalarField& ptf
+    const buoyantPressureFvPatchScalarField& ptf
 )
 :
     fixedGradientFvPatchScalarField(ptf),
@@ -89,10 +89,10 @@ fixedFluxBuoyantPressureFvPatchScalarField
 {}
 
 
-fixedFluxBuoyantPressureFvPatchScalarField::
-fixedFluxBuoyantPressureFvPatchScalarField
+buoyantPressureFvPatchScalarField::
+buoyantPressureFvPatchScalarField
 (
-    const fixedFluxBuoyantPressureFvPatchScalarField& ptf,
+    const buoyantPressureFvPatchScalarField& ptf,
     const DimensionedField<scalar, volMesh>& iF
 )
 :
@@ -103,7 +103,7 @@ fixedFluxBuoyantPressureFvPatchScalarField
 
 // * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //
 
-void fixedFluxBuoyantPressureFvPatchScalarField::updateCoeffs()
+void buoyantPressureFvPatchScalarField::updateCoeffs()
 {
     if (updated())
     {
@@ -134,7 +134,7 @@ void fixedFluxBuoyantPressureFvPatchScalarField::updateCoeffs()
 }
 
 
-void fixedFluxBuoyantPressureFvPatchScalarField::write(Ostream& os) const
+void buoyantPressureFvPatchScalarField::write(Ostream& os) const
 {
     fixedGradientFvPatchScalarField::write(os);
     os.writeKeyword("rho") << rhoName_ << token::END_STATEMENT << nl;
@@ -147,7 +147,7 @@ void fixedFluxBuoyantPressureFvPatchScalarField::write(Ostream& os) const
 makePatchTypeField
 (
     fvPatchScalarField,
-    fixedFluxBuoyantPressureFvPatchScalarField
+    buoyantPressureFvPatchScalarField
 );
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
diff --git a/tutorials/heatTransfer/buoyantBoussinesqPisoFoam/hotRoom/0/p b/tutorials/heatTransfer/buoyantBoussinesqPisoFoam/hotRoom/0/p
index 2014ca6e8c05c4140f60fa97f5d77545a31b68c8..502fb88dfaf0b335774fa4a45714c68078bec5ad 100644
--- a/tutorials/heatTransfer/buoyantBoussinesqPisoFoam/hotRoom/0/p
+++ b/tutorials/heatTransfer/buoyantBoussinesqPisoFoam/hotRoom/0/p
@@ -22,21 +22,21 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
diff --git a/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/hotRoom/0/p b/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/hotRoom/0/p
index 2014ca6e8c05c4140f60fa97f5d77545a31b68c8..502fb88dfaf0b335774fa4a45714c68078bec5ad 100644
--- a/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/hotRoom/0/p
+++ b/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/hotRoom/0/p
@@ -22,21 +22,21 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
diff --git a/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/iglooWithFridges/0/p b/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/iglooWithFridges/0/p
index 2b90b18e74e8b30535be502ed783da524727c7df..6835a61b1258dc947b0fcf662a11290acf90045f 100644
--- a/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/iglooWithFridges/0/p
+++ b/tutorials/heatTransfer/buoyantBoussinesqSimpleFoam/iglooWithFridges/0/p
@@ -22,28 +22,28 @@ boundaryField
 {
     ground
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     igloo_region0
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     twoFridgeFreezers_seal_0
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
 
     twoFridgeFreezers_herring_1
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         rho             rhok;
         value           uniform 0;
     }
diff --git a/tutorials/heatTransfer/buoyantPisoFoam/hotRoom/0/p b/tutorials/heatTransfer/buoyantPisoFoam/hotRoom/0/p
index 188522464acb9b347136541e983dc3d02d2b0d32..349cfb544ecd2067ace69184f34c7414544584b0 100644
--- a/tutorials/heatTransfer/buoyantPisoFoam/hotRoom/0/p
+++ b/tutorials/heatTransfer/buoyantPisoFoam/hotRoom/0/p
@@ -22,19 +22,19 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 }
diff --git a/tutorials/heatTransfer/buoyantSimpleFoam/hotRoom/0/p b/tutorials/heatTransfer/buoyantSimpleFoam/hotRoom/0/p
index 188522464acb9b347136541e983dc3d02d2b0d32..349cfb544ecd2067ace69184f34c7414544584b0 100644
--- a/tutorials/heatTransfer/buoyantSimpleFoam/hotRoom/0/p
+++ b/tutorials/heatTransfer/buoyantSimpleFoam/hotRoom/0/p
@@ -22,19 +22,19 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 1e5;
     }
 }
diff --git a/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoom/0/p b/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoom/0/p
index bb1ff51259ac287aadde6157a1719177c2bfdb7c..f36884c5b2bea50659ca7ac526c853470f1aece7 100644
--- a/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoom/0/p
+++ b/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoom/0/p
@@ -22,25 +22,25 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     box
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 }
diff --git a/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoomFvDOM/0/p b/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoomFvDOM/0/p
index bb1ff51259ac287aadde6157a1719177c2bfdb7c..f36884c5b2bea50659ca7ac526c853470f1aece7 100644
--- a/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoomFvDOM/0/p
+++ b/tutorials/heatTransfer/buoyantSimpleRadiationFoam/hotRadiationRoomFvDOM/0/p
@@ -22,25 +22,25 @@ boundaryField
 {
     floor
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     ceiling
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     fixedWalls
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 
     box
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           uniform 100000;
     }
 }
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
index 8a2a5d0a87887b19799c65d58f14a8c7aaf03b13..385ded3bb382650a44976dea9ec855adf5df7ebe 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
@@ -22,33 +22,33 @@ boundaryField
 {
     minX
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
     maxX
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
 
     minY
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
     maxY
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
     minZ
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
     maxZ
     {
-        type            fixedFluxBuoyantPressure;
+        type            buoyantPressure;
         value           1e5;
     }
 }
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
index 7ee62d4bd7ab20aa698476583b6260258630fc37..6c80174e3550fcc2163435f18ae6404a26615f1c 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
@@ -232,42 +232,42 @@ dictionaryReplacement
         {
             minX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             minY
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             minZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_leftSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_heater
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_rightSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
         }
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
index f4f44ee6d49cc25317612a2ae6cd4355296aa3e1..a437f44d5d5cd79a7aa466342d7df83797b252db 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
@@ -231,7 +231,7 @@ dictionaryReplacement
         {
             minX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxX
@@ -249,34 +249,34 @@ dictionaryReplacement
 
             minY
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
 
             minZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
 
             topAir_to_leftSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             topAir_to_heater
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             topAir_to_rightSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
         }
diff --git a/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/bottomAir/changeDictionaryDict b/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/bottomAir/changeDictionaryDict
index afb08c33c836b32175a2dbd01c0e6979432403a0..f3d186d1e81fb8541695551656604c4d3efaa6a4 100644
--- a/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/bottomAir/changeDictionaryDict
+++ b/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/bottomAir/changeDictionaryDict
@@ -255,42 +255,42 @@ dictionaryReplacement
         {
             minX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             minY
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             minZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_leftSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_heater
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             bottomAir_to_rightSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
         }
diff --git a/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/topAir/changeDictionaryDict b/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/topAir/changeDictionaryDict
index 51104c879f112b121569914cf44aa57474e85a7f..ad82755773e1968fef95dc1aa7c688d5709e2374 100644
--- a/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/topAir/changeDictionaryDict
+++ b/tutorials/mesh/snappyHexMesh/multiRegionMesh/system/topAir/changeDictionaryDict
@@ -265,7 +265,7 @@ dictionaryReplacement
         {
             minX
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxX
@@ -283,34 +283,34 @@ dictionaryReplacement
 
             maxY
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
 
             minZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             maxZ
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
 
             topAir_to_leftSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             topAir_to_heater
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
             topAir_to_rightSolid
             {
-                type            fixedFluxBuoyantPressure;
+                type            buoyantPressure;
                 value           1e5;
             }
         }
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.H b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.H
similarity index 78%
rename from src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.H
rename to src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.H
index ec5dc7dd990d69170621c253ca5b73b5d9e91b74..d698487e3650db3d1ea274cc3e649a84b6f68941 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/fixedFluxBuoyantPressure/fixedFluxBuoyantPressureFvPatchScalarField.H
+++ b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.H
@@ -23,7 +23,7 @@ License
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 Class
-    Foam::fixedFluxBuoyantPressureFvPatchScalarField
+    Foam::buoyantPressureFvPatchScalarField
 
 Description
     Set the pressure gradient boundary condition appropriately for buoyant flow.
@@ -32,12 +32,12 @@ Description
     appropriately.  Otherwise assume the variable is the static pressure.
 
 SourceFiles
-    fixedFluxBuoyantPressureFvPatchScalarField.C
+    buoyantPressureFvPatchScalarField.C
 
 \*---------------------------------------------------------------------------*/
 
-#ifndef fixedFluxBuoyantPressureFvPatchScalarFields_H
-#define fixedFluxBuoyantPressureFvPatchScalarFields_H
+#ifndef buoyantPressureFvPatchScalarFields_H
+#define buoyantPressureFvPatchScalarFields_H
 
 #include "fvPatchFields.H"
 #include "fixedGradientFvPatchFields.H"
@@ -48,10 +48,10 @@ namespace Foam
 {
 
 /*---------------------------------------------------------------------------*\
-                  Class fixedFluxBuoyantPressureFvPatch Declaration
+                  Class buoyantPressureFvPatch Declaration
 \*---------------------------------------------------------------------------*/
 
-class fixedFluxBuoyantPressureFvPatchScalarField
+class buoyantPressureFvPatchScalarField
 :
     public fixedGradientFvPatchScalarField
 {
@@ -64,20 +64,20 @@ class fixedFluxBuoyantPressureFvPatchScalarField
 public:
 
     //- Runtime type information
-    TypeName("fixedFluxBuoyantPressure");
+    TypeName("buoyantPressure");
 
 
     // Constructors
 
         //- Construct from patch and internal field
-        fixedFluxBuoyantPressureFvPatchScalarField
+        buoyantPressureFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&
         );
 
         //- Construct from patch, internal field and dictionary
-        fixedFluxBuoyantPressureFvPatchScalarField
+        buoyantPressureFvPatchScalarField
         (
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
@@ -85,19 +85,19 @@ public:
         );
 
         //- Construct by mapping given
-        //  fixedFluxBuoyantPressureFvPatchScalarField onto a new patch
-        fixedFluxBuoyantPressureFvPatchScalarField
+        //  buoyantPressureFvPatchScalarField onto a new patch
+        buoyantPressureFvPatchScalarField
         (
-            const fixedFluxBuoyantPressureFvPatchScalarField&,
+            const buoyantPressureFvPatchScalarField&,
             const fvPatch&,
             const DimensionedField<scalar, volMesh>&,
             const fvPatchFieldMapper&
         );
 
         //- Construct as copy
-        fixedFluxBuoyantPressureFvPatchScalarField
+        buoyantPressureFvPatchScalarField
         (
-            const fixedFluxBuoyantPressureFvPatchScalarField&
+            const buoyantPressureFvPatchScalarField&
         );
 
         //- Construct and return a clone
@@ -105,14 +105,14 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new fixedFluxBuoyantPressureFvPatchScalarField(*this)
+                new buoyantPressureFvPatchScalarField(*this)
             );
         }
 
         //- Construct as copy setting internal field reference
-        fixedFluxBuoyantPressureFvPatchScalarField
+        buoyantPressureFvPatchScalarField
         (
-            const fixedFluxBuoyantPressureFvPatchScalarField&,
+            const buoyantPressureFvPatchScalarField&,
             const DimensionedField<scalar, volMesh>&
         );
 
@@ -124,7 +124,7 @@ public:
         {
             return tmp<fvPatchScalarField>
             (
-                new fixedFluxBuoyantPressureFvPatchScalarField(*this, iF)
+                new buoyantPressureFvPatchScalarField(*this, iF)
             );
         }
 